@@ -725,10 +725,10 @@ void MainWindow::scanDevices()
     deviceScanner().start();
 }
 
-void MainWindow::on_m_DeviceScanner_progress(const QString& device_node, int percent)
+void MainWindow::on_m_DeviceScanner_progress(const QString& deviceNode, int percent)
 {
     scanProgressDialog().setProgress(percent);
-    scanProgressDialog().setDeviceName(device_node);
+    scanProgressDialog().setDeviceName(deviceNode);
 }
 
 void MainWindow::on_m_DeviceScanner_finished()
