@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(NEWDIALOG__H)
+#if !defined(NEWDIALOG_H)
 
-#define NEWDIALOG__H
+#define NEWDIALOG_H
 
 #include "gui/sizedialogbase.h"
 
